# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:09 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2005 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2005;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2005/] (retrieved on 2016-11-07). Visit the URL for the full contents.",
  entries     => [
                   { module => "Acme::Code::FreedomFighter" },
                   { module => "Acme::Drunk" },
                   { module => "Acme::Intraweb" },
                   { module => "Acme::Pony" },
                   { module => "Archive::Extract" },
                   { module => "Attribute::Handlers" },
                   { module => "Attribute::Overload" },
                   { module => "Attribute::TieClasses" },
                   { module => "Benchmark" },
                   { module => "CGI::Application" },
                   { module => "CGI::Untaint" },
                   { module => "CPAN::Mini" },
                   { module => "CPANPLUS" },
                   { module => "Cache::Cache" },
                   { module => "Class::Accessor::Chained" },
                   { module => "Class::DBI" },
                   { module => "Class::Data::Inheritable" },
                   { module => "Class::ISA" },
                   { module => "Class::MethodMaker" },
                   { module => "Class::Multimethods" },
                   { module => "Class::Virtual" },
                   { module => "Crypt::RC4" },
                   { module => "Crypt::Solitaire" },
                   { module => "DBD::SQLite" },
                   { module => "DBI" },
                   { module => "Data::Dimensions" },
                   { module => "Data::Dumper" },
                   { module => "Data::Dumper::Simple" },
                   { module => "Data::Structure::Util" },
                   { module => "Data::UUID" },
                   { module => "Date::Christmas" },
                   { module => "Date::Parse" },
                   { module => "DateTime" },
                   { module => "Devel::DProf" },
                   { module => "Devel::Size" },
                   { module => "Devel::Trace" },
                   { module => "Encode" },
                   { module => "Exporter" },
                   { module => "Exporter::Simple" },
                   { module => "ExtUtils::ModuleMaker" },
                   { module => "File::Find" },
                   { module => "File::Find::Rule" },
                   { module => "File::MMagic" },
                   { module => "File::Remote" },
                   { module => "File::Spec" },
                   { module => "File::chdir" },
                   { module => "Filesys::Virtual" },
                   { module => "GD" },
                   { module => "Getopt::Long" },
                   { module => "GraphViz" },
                   { module => "HTML::Entities" },
                   { module => "Hook::LexWrap" },
                   { module => "IO::AtomicFile" },
                   { module => "Image::Imlib2" },
                   { module => "Image::Size" },
                   { module => "Inline" },
                   { module => "Inline::Files" },
                   { module => "Inline::TT" },
                   { module => "LWP::Simple" },
                   { module => "Lingua::EN::Numbers::Ordinate" },
                   { module => "Lingua::PT::Nums2Ords" },
                   { module => "List::Util" },
                   { module => "Mac::Glue" },
                   { module => "Mail::Audit" },
                   { module => "Mail::ListDetector" },
                   { module => "Mail::SpamAssassin" },
                   { module => "Math::BigInt" },
                   { module => "Memoize" },
                   { module => "Module::Pluggable" },
                   { module => "Object::Realize::Later" },
                   { module => "PAR" },
                   { module => "PDF::Reuse" },
                   { module => "POE" },
                   { module => "POE::Component::Client::HTTP" },
                   { module => "POE::Component::IRC" },
                   { module => "PPerl" },
                   { module => "Parse::RecDescent" },
                   { module => "Pixie" },
                   { module => "Pod::Coverage" },
                   { module => "Proc::Daemon" },
                   { module => "Quantum::Superpositions" },
                   { module => "Regexp::Common" },
                   { module => "SQL::Abstract" },
                   { module => "Scalar::Util" },
                   { module => "Spreadsheet::WriteExcel" },
                   { module => "Storable" },
                   { module => "String::ShellQuote" },
                   { module => "Symbol::Approx::Sub" },
                   { module => "Sys::Hostname" },
                   { module => "Template" },
                   { module => "Template::Extract" },
                   { module => "Term::ANSIColor" },
                   { module => "Term::ProgressBar" },
                   { module => "Test::Builder" },
                   { module => "Test::Inline" },
                   { module => "Test::MockObject" },
                   { module => "Test::More" },
                   { module => "Text::Autoformat" },
                   { module => "Text::Glob" },
                   { module => "Text::Table" },
                   { module => "Text::Unidecode" },
                   { module => "Tie::DBI" },
                   { module => "Tie::File" },
                   { module => "Tie::Hash::Cannabinol" },
                   { module => "Tie::HashDefaults" },
                   { module => "Tie::Scalar::Timeout" },
                   { module => "Time::Local" },
                   { module => "Time::Object" },
                   { module => "URI::Find" },
                   { module => "WWW::Mechanize" },
                   { module => "XML::Grove" },
                   { module => "XML::Handler::AxPoint" },
                   { module => "XML::LibXML" },
                   { module => "XML::SAX" },
                   { module => "XML::XPath" },
                   { module => "YAML" },
                   { module => "diagnostics" },
                   { module => "only" },
                   { module => "Interpolation" },
                   { module => "Bundle::PerlPoint" },
                   { module => "Math::Matrix" },
                   { module => "bignum" },
                   { module => "Acme::Bleach" },
                   { module => "CGI::Ajax" },
                   { module => "Make" },
                   { module => "ppt" },
                   { module => "Perl6::Junction" },
                   { module => "Set::Array" },
                   { module => "Set::Bag" },
                   { module => "Set::IntRange" },
                   { module => "Set::IntSpan" },
                   { module => "Set::Scalar" },
                   { module => "HTML::FromANSI" },
                   { module => "Regexp::English" },
                   { module => "Rx" },
                   { module => "YAPE::Regex" },
                   { module => "YAPE::Regex::Explain" },
                   { module => "Regexp::Keep" },
                   { module => "HTML::Lint" },
                   { module => "Clone" },
                   { module => "Data::COW" },
                   { module => "XML::RSS::SimpleGen" },
                   { module => "Acme::POE::Knee" },
                   { module => "Regexp::Assemble" },
                   { module => "Regexp::List" },
                   { module => "Test::Perl::Critic" },
                   { module => "PPI" },
                   { module => "Perl::Compare" },
                   { module => "Want" },
                   { module => "Module::CoreList" },
                   { module => "Sort::Maker" },
                   { module => "enum" },
                   { module => "enum::hash" },
                   { module => "Acme::Curses::Marquee" },
                   { module => "Text::FIGlet" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2005",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2005

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2005 - Modules mentioned in Perl Advent Calendar 2005

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2005 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2005), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2005.

This list is generated by extracting module names mentioned in [http://perladvent.org/2005/] (retrieved on 2016-11-07). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<Acme::Code::FreedomFighter>

=item * L<Acme::Drunk>

=item * L<Acme::Intraweb>

=item * L<Acme::Pony>

=item * L<Archive::Extract>

=item * L<Attribute::Handlers>

=item * L<Attribute::Overload>

=item * L<Attribute::TieClasses>

=item * L<Benchmark>

=item * L<CGI::Application>

=item * L<CGI::Untaint>

=item * L<CPAN::Mini>

=item * L<CPANPLUS>

=item * L<Cache::Cache>

=item * L<Class::Accessor::Chained>

=item * L<Class::DBI>

=item * L<Class::Data::Inheritable>

=item * L<Class::ISA>

=item * L<Class::MethodMaker>

=item * L<Class::Multimethods>

=item * L<Class::Virtual>

=item * L<Crypt::RC4>

=item * L<Crypt::Solitaire>

=item * L<DBD::SQLite>

=item * L<DBI>

=item * L<Data::Dimensions>

=item * L<Data::Dumper>

=item * L<Data::Dumper::Simple>

=item * L<Data::Structure::Util>

=item * L<Data::UUID>

=item * L<Date::Christmas>

=item * L<Date::Parse>

=item * L<DateTime>

=item * L<Devel::DProf>

=item * L<Devel::Size>

=item * L<Devel::Trace>

=item * L<Encode>

=item * L<Exporter>

=item * L<Exporter::Simple>

=item * L<ExtUtils::ModuleMaker>

=item * L<File::Find>

=item * L<File::Find::Rule>

=item * L<File::MMagic>

=item * L<File::Remote>

=item * L<File::Spec>

=item * L<File::chdir>

=item * L<Filesys::Virtual>

=item * L<GD>

=item * L<Getopt::Long>

=item * L<GraphViz>

=item * L<HTML::Entities>

=item * L<Hook::LexWrap>

=item * L<IO::AtomicFile>

=item * L<Image::Imlib2>

=item * L<Image::Size>

=item * L<Inline>

=item * L<Inline::Files>

=item * L<Inline::TT>

=item * L<LWP::Simple>

=item * L<Lingua::EN::Numbers::Ordinate>

=item * L<Lingua::PT::Nums2Ords>

=item * L<List::Util>

=item * L<Mac::Glue>

=item * L<Mail::Audit>

=item * L<Mail::ListDetector>

=item * L<Mail::SpamAssassin>

=item * L<Math::BigInt>

=item * L<Memoize>

=item * L<Module::Pluggable>

=item * L<Object::Realize::Later>

=item * L<PAR>

=item * L<PDF::Reuse>

=item * L<POE>

=item * L<POE::Component::Client::HTTP>

=item * L<POE::Component::IRC>

=item * L<PPerl>

=item * L<Parse::RecDescent>

=item * L<Pixie>

=item * L<Pod::Coverage>

=item * L<Proc::Daemon>

=item * L<Quantum::Superpositions>

=item * L<Regexp::Common>

=item * L<SQL::Abstract>

=item * L<Scalar::Util>

=item * L<Spreadsheet::WriteExcel>

=item * L<Storable>

=item * L<String::ShellQuote>

=item * L<Symbol::Approx::Sub>

=item * L<Sys::Hostname>

=item * L<Template>

=item * L<Template::Extract>

=item * L<Term::ANSIColor>

=item * L<Term::ProgressBar>

=item * L<Test::Builder>

=item * L<Test::Inline>

=item * L<Test::MockObject>

=item * L<Test::More>

=item * L<Text::Autoformat>

=item * L<Text::Glob>

=item * L<Text::Table>

=item * L<Text::Unidecode>

=item * L<Tie::DBI>

=item * L<Tie::File>

=item * L<Tie::Hash::Cannabinol>

=item * L<Tie::HashDefaults>

=item * L<Tie::Scalar::Timeout>

=item * L<Time::Local>

=item * L<Time::Object>

=item * L<URI::Find>

=item * L<WWW::Mechanize>

=item * L<XML::Grove>

=item * L<XML::Handler::AxPoint>

=item * L<XML::LibXML>

=item * L<XML::SAX>

=item * L<XML::XPath>

=item * L<YAML>

=item * L<diagnostics>

=item * L<only>

=item * L<Interpolation>

=item * L<Bundle::PerlPoint>

=item * L<Math::Matrix>

=item * L<bignum>

=item * L<Acme::Bleach>

=item * L<CGI::Ajax>

=item * L<Make>

=item * L<ppt>

=item * L<Perl6::Junction>

=item * L<Set::Array>

=item * L<Set::Bag>

=item * L<Set::IntRange>

=item * L<Set::IntSpan>

=item * L<Set::Scalar>

=item * L<HTML::FromANSI>

=item * L<Regexp::English>

=item * L<Rx>

=item * L<YAPE::Regex>

=item * L<YAPE::Regex::Explain>

=item * L<Regexp::Keep>

=item * L<HTML::Lint>

=item * L<Clone>

=item * L<Data::COW>

=item * L<XML::RSS::SimpleGen>

=item * L<Acme::POE::Knee>

=item * L<Regexp::Assemble>

=item * L<Regexp::List>

=item * L<Test::Perl::Critic>

=item * L<PPI>

=item * L<Perl::Compare>

=item * L<Want>

=item * L<Module::CoreList>

=item * L<Sort::Maker>

=item * L<enum>

=item * L<enum::hash>

=item * L<Acme::Curses::Marquee>

=item * L<Text::FIGlet>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2005>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2005>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2005>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
